"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const xrefparser_1 = require("xrefparser");
const help_1 = require("../help");
const editor_1 = require("../editor");
class SearchCommand {
    constructor(config) {
        this.reponame = '';
        this.batch = false;
        this.openSources = false;
        this.jsonOutput = false;
        this.config = config;
    }
    execute(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const xreffiles = this.config.loadRepo(this.reponame);
            const searcher = new xrefparser_1.Searcher(xreffiles);
            let result = [];
            if (this.field !== undefined) {
                result = searcher.getFieldReferences(this.field, this.table, this.hasUpdates);
            }
            else if (this.table !== undefined) {
                result = searcher.getTabelReferences(this.table, this.hasCreates, this.hasUpdates, this.hasDeletes);
            }
            else if (this.db !== undefined) {
                result = searcher.getDatabaseReferences(this.db);
            }
            if (this.openSources) {
                const editor = new editor_1.Editor(this.config);
                yield editor.open(result.map(item => item.sourcefile));
            }
            else {
                if (this.jsonOutput) {
                    console.log(JSON.stringify(result.map(item => item.sourcefile), undefined, 2));
                }
                else {
                    result.map(item => item.sourcefile).forEach(source => {
                        console.log(source);
                    });
                }
                if (!this.batch) {
                    console.log('count=', result.length);
                }
            }
        });
    }
    validate(params) {
        const options = params['options'];
        if (options['help'] === true) {
            const help = new help_1.Help();
            help.searchCommand();
            process.exit(0);
        }
        let reponame = options['name'];
        if (reponame === undefined) {
            if (this.config.data.current === undefined) {
                console.error('Error: no repo specified, no current repo');
                return false;
            }
            else {
                reponame = this.config.data.current;
            }
        }
        this.field = options['field'];
        if (this.field === null) {
            console.error('Field name for --field option needs to be specified');
            return false;
        }
        this.table = options['table'];
        if (this.table === null) {
            console.error('Table name for --table option needs to be specified');
            return false;
        }
        this.db = options['db'];
        if (this.db === null) {
            console.error('Database name for --db option needs to be specified');
            return false;
        }
        this.hasCreates = this.parseCrudValue(options['create']);
        this.hasUpdates = this.parseCrudValue(options['update']);
        this.hasDeletes = this.parseCrudValue(options['delete']);
        if (options['batch'] === true) {
            this.batch = true;
        }
        if (options['open'] === true) {
            this.openSources = true;
        }
        if (options['json'] === true) {
            this.jsonOutput = true;
        }
        this.reponame = reponame;
        return true;
    }
    parseCrudValue(value) {
        if (value !== undefined) {
            // the default value = true, so '--update' and '--update true' are the same
            if (value === null) {
                value = 'true';
            }
            value = value.toLowerCase();
            if (value === 'true' || value === 'yes') {
                return true;
            }
            else if (value === 'false' || value === 'no') {
                return false;
            }
        }
        return undefined;
    }
}
exports.SearchCommand = SearchCommand;
//# sourceMappingURL=search.js.map