"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = __importStar(require("path"));
const fs = __importStar(require("fs"));
class Config {
    constructor() {
        this.data = new ConfigData();
        this.configRootDir = '';
        this.reposDir = '';
        this.configFile = '';
    }
    initialize() {
        this.checkDirs();
        this.data = this.loadConfig();
    }
    checkDirs() {
        const userDir = require('os').homedir();
        this.configRootDir = userDir + path.sep + '.xrefcli';
        this.reposDir = this.configRootDir + path.sep + 'repos';
        if (!fs.existsSync(this.configRootDir)) {
            fs.mkdirSync(this.configRootDir);
        }
        if (!fs.existsSync(this.reposDir)) {
            fs.mkdirSync(this.reposDir);
        }
    }
    loadConfig() {
        this.configFile = this.configRootDir + path.sep + 'xrefconfig.json';
        let config = new ConfigData();
        if (fs.existsSync(this.configFile)) {
            config = Object.assign(new ConfigData(), require(this.configFile));
        }
        return config;
    }
    saveConfig() {
        fs.writeFileSync(this.configFile, JSON.stringify(this.data, null, 2));
    }
    addRepo(repo) {
        if (this.data.repos.findIndex(item => item.name === repo.name) === -1) {
            this.data.repos.push(repo);
        }
    }
    removeRepo(reponame) {
        reponame = reponame.toLowerCase();
        if (this.data.repos.findIndex(item => item.name === reponame) === -1) {
            console.error(`Error: repo '${reponame}' not found`);
            process.exit(1);
        }
        const repofile = this.getRepoFilename(reponame);
        fs.unlinkSync(repofile);
        this.data.repos = this.data.repos.filter(item => item.name !== reponame);
    }
    repoExists(reponame) {
        return (this.data.repos.findIndex(item => item.name === reponame) !== -1);
    }
    writeRepoData(reponame, xrefdata) {
        const repofilename = this.getRepoFilename(reponame);
        fs.writeFileSync(repofilename, JSON.stringify(xrefdata, undefined, 2));
        return true;
    }
    getRepo(reponame = '') {
        if (reponame === '') {
            reponame = this.data.current;
        }
        const repo = this.data.repos.filter(item => item.name === reponame.toLowerCase())[0];
        return repo;
    }
    getRepoFilename(reponame) {
        const repofilename = this.reposDir + path.sep + reponame + '.json';
        return repofilename;
    }
    loadRepo(reponame) {
        const repofile = this.getRepoFilename(reponame);
        const xreffile = require(repofile);
        return xreffile;
    }
}
exports.Config = Config;
class ConfigData {
    constructor() {
        this.current = '';
        this.editor = { name: 'vscode', executable: 'code', open: '--goto %s' };
        this.repos = [];
    }
}
exports.ConfigData = ConfigData;
//# sourceMappingURL=config.js.map